/* CSS31_ style sheet for the output of Docutils HTML writers.             */
/* Rules for easy reading and pre-defined style variants.		   */
/*                                                                         */
/* :Author: Günter Milde, based on html4css1.css by David Goodger          */
/* :Id: $Id: plain.css 8120 2017-06-22 21:02:40Z milde $               */
/* :Copyright: © 2015 Günter Milde.                                        */
/* :License: Released under the terms of the `2-Clause BSD license`_,      */
/*    in short:                                                            */
/*                                                                         */
/*    Copying and distribution of this file, with or without modification, */
/*    are permitted in any medium without royalty provided the copyright   */
/*    notice and this notice are preserved.                                */
/*    	     	      	     	 					   */
/*    This file is offered as-is, without any warranty.                    */
/*                                                                         */
/* .. _2-Clause BSD license: http://www.spdx.org/licenses/BSD-2-Clause     */
/* .. _CSS3: http://www.w3.org/TR/CSS3		        		   */


/* Document Structure */
/* ****************** */

/* "page layout" */
body {
  padding: 0 5%;
  margin: 8px 0;
}
div.document {
  line-height:1.3;
  counter-reset: table;
  /* counter-reset: figure; */
  /* avoid long lines --> better reading */
  /* OTOH: lines should not be too short because of missing hyphenation, */
  max-width: 50em;
  margin: auto;
}

/* Sections */

/* Transitions */

hr.docutils {
  width: 80%;
  margin-top: 1em;
  margin-bottom: 1em;
  clear: both;
}

/* Paragraphs               */
/* ==========               */

/* vertical space (parskip) */
p, ol, ul, dl,
div.line-block,
table{
  margin-top: 0.5em;
  margin-bottom: 0.5em;
}
h1, h2, h3, h4, h5, h6,
dl > dd {
  margin-bottom: 0.5em;
}

/* Lists                    */
/* ==========               */

/* Definition Lists         */

dl > dd > p:first-child { margin-top: 0; }
/* :last-child is not part of CSS 2.1 (introduced in CSS 3) */
dl > dd > p:last-child  { margin-bottom: 0; }

/* lists nested in definition lists */
/* :only-child is not part of CSS 2.1 (introduced in CSS 3) */
dd > ul:only-child, dd > ol:only-child { padding-left: 1em; }

/* Description Lists */
/* styled like in most dictionaries, encyclopedias etc. */
dl.description > dt {
  font-weight: bold;
  clear: left;
  float: left;
  margin: 0;
  padding: 0;
  padding-right: 0.5em;
}

/* Field Lists */

/* example for custom field-name width */
dl.field-list.narrow > dd {
  margin-left: 5em;
}
/* run-in: start field-body on same line after long field names */
dl.field-list.run-in > dd p {
  display: block;
}

/* Bibliographic Fields */

/* generally, bibliographic fields use special definition list dl.docinfo */
/* but dedication and abstract are placed into "topic" divs */
div.abstract p.topic-title {
  text-align: center;
}
div.dedication {
  margin: 2em 5em;
  text-align: center;
  font-style: italic;
}
div.dedication p.topic-title {
  font-style: normal;
}

/* Citations */
dl.citation dt.label {
  font-weight: bold;
}
span.fn-backref {
  font-weight: normal;
}

/* Text Blocks           */
/* ============          */

/* Literal Blocks           */
pre.literal-block, pre.doctest-block,
pre.math, pre.code {
  margin-left: 1.5em;
  margin-right: 1.5em
}

/* Block Quotes             */

blockquote,
div.topic {
  margin-left: 1.5em;
  margin-right: 1.5em
}
blockquote > table,
div.topic > table {
  margin-top: 0;
  margin-bottom: 0;
}
blockquote p.attribution,
div.topic p.attribution {
  text-align: right;
  margin-left: 20%;
}

/* Tables                   */
/* ======                   */

/* th { vertical-align: bottom; } */

table tr { text-align: left; }

/* "booktabs" style (no vertical lines) */
table.booktabs {
  border: 0;
  border-top: 2px solid;
  border-bottom: 2px solid;
  border-collapse: collapse;
}
table.booktabs * {
  border: 0;
}
table.booktabs th {
  border-bottom: thin solid;
}

/* numbered tables (counter defined in div.document) */
table.numbered > caption:before {
  counter-increment: table;
  content: "Table " counter(table) ": ";
  font-weight: bold;
}

/* Explicit Markup Blocks   */
/* ======================   */

/* Footnotes and Citations  */
/* -----------------------  */

/* line on the left */
dl.footnote {
  padding-left: 1ex;
  border-left: solid;
  border-left-width: thin;
}

/* Directives               */
/* ----------               */

/* Body Elements            */
/* ~~~~~~~~~~~~~            */

/* Images and Figures */

/* let content flow to the side of aligned images and figures */
.figure.align-left,
img.align-left,
object.align-left {
  display: block;
  clear: left;
  float: left;
  margin-right: 1em
}
.figure.align-right,
img.align-right,
object.align-right {
  display: block;
  clear: right;
  float: right;
  margin-left: 1em
}
/* Stop floating sidebars, images and figures at section level 1,2,3 */
h1, h2, h3 { clear: both; }

/* Sidebar */

/* Move into the margin. In a layout with fixed margins, */
/* it can be moved into the margin completely.		 */
div.sidebar {
  width: 30%;
  max-width: 26em;
  margin-left: 1em;
  margin-right: -5.5%;
  background-color: #ffffee ;
}

/* Code                     */

pre.code, code { background-color: #eeeeee }
pre.code .ln { color: gray; } /* line numbers */
/* basic highlighting: for a complete scheme, see */
/* http://docutils.sourceforge.net/sandbox/stylesheets/ */
pre.code .comment, code .comment { color: #5C6576 }
pre.code .keyword, code .keyword { color: #3B0D06; font-weight: bold }
pre.code .literal.string, code .literal.string { color: #0C5404 }
pre.code .name.builtin, code .name.builtin { color: #352B84 }
pre.code .deleted, code .deleted { background-color: #DEB0A1}
pre.code .inserted, code .inserted { background-color: #A3D289}

/* Math                     */
/* styled separately (see math.css for math-output=HTML) */

/* Epigraph                 */
/* Highlights               */
/* Pull-Quote               */
/* Compound Paragraph       */
/* Container                */

/* can be styled in a custom stylesheet */

/* Document Header and Footer */

div.footer, div.header {
  clear: both;
  font-size: smaller;
}

/* Inline Markup            */
/* =============            */

/* Emphasis                 */
/*   em                     */
/* Strong Emphasis          */
/*   strong		    */
/* Interpreted Text         */
/*   span.interpreted  	    */
/* Title Reference 	    */
/*   cite		    */
/* Inline Literals          */
/* possible values: normal, nowrap, pre, pre-wrap, pre-line */
/*   span.docutils.literal { white-space: pre-wrap; } */

/* Hyperlink References     */
a { text-decoration: none; }

/* External Targets         */
/*   span.target.external   */
/* Internal Targets  	    */
/*   span.target.internal   */
/* Footnote References      */
/*   a.footnote-reference   */
/* Citation References      */
/*   a.citation-reference   */
